@@ -110,4 +110,4 @@ class GetBookmarksRequest(BaseRequestObject):
         return 'BookmarksResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, BookmarksResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), BookmarksResponse)
