@@ -103,4 +103,4 @@ class GetCommentsOnlineRequest(BaseRequestObject):
         return 'CommentsResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, CommentsResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), CommentsResponse)
