@@ -116,4 +116,4 @@ class GetDocumentDrawingObjectsRequest(BaseRequestObject):
         return 'DrawingObjectsResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, DrawingObjectsResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), DrawingObjectsResponse)
