@@ -119,4 +119,4 @@ class GetDocumentPropertyRequest(BaseRequestObject):
         return 'DocumentPropertyResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, DocumentPropertyResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), DocumentPropertyResponse)
