@@ -123,4 +123,4 @@ class GetHeaderFootersRequest(BaseRequestObject):
         return 'HeaderFootersResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, HeaderFootersResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), HeaderFootersResponse)
