@@ -81,4 +81,4 @@ class GetInfoRequest(BaseRequestObject):
         return 'InfoResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, InfoResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), InfoResponse)
