@@ -125,4 +125,4 @@ class GetParagraphListFormatRequest(BaseRequestObject):
         return 'ParagraphListFormatResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, ParagraphListFormatResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), ParagraphListFormatResponse)
