@@ -125,4 +125,4 @@ class GetRangeTextRequest(BaseRequestObject):
         return 'RangeTextResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, RangeTextResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), RangeTextResponse)
