@@ -121,4 +121,4 @@ class GetRunOnlineRequest(BaseRequestObject):
         return 'RunResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, RunResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), RunResponse)
