@@ -128,4 +128,4 @@ class GetTableCellRequest(BaseRequestObject):
         return 'TableCellResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, TableCellResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), TableCellResponse)
