@@ -143,4 +143,4 @@ class InsertFieldRequest(BaseRequestObject):
         return 'FieldResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, FieldResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), FieldResponse)
