@@ -142,4 +142,4 @@ class InsertHeaderFooterRequest(BaseRequestObject):
         return 'HeaderFooterResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, HeaderFooterResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), HeaderFooterResponse)
