@@ -133,4 +133,4 @@ class InsertListRequest(BaseRequestObject):
         return 'ListResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, ListResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), ListResponse)
