@@ -133,4 +133,4 @@ class ReplaceTextRequest(BaseRequestObject):
         return 'ReplaceTextResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, ReplaceTextResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), ReplaceTextResponse)
