@@ -142,4 +142,4 @@ class UpdateCustomXmlPartRequest(BaseRequestObject):
         return 'CustomXmlPartResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, CustomXmlPartResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), CustomXmlPartResponse)
