@@ -51,7 +51,6 @@ class TiffSaveOptionsData(object):
         'file_name': 'str',
         'flat_opc_xml_mapping_only': 'bool',
         'iml_rendering_mode': 'str',
-        'save_format': 'str',
         'update_created_time_property': 'bool',
         'update_fields': 'bool',
         'update_last_printed_property': 'bool',
@@ -77,6 +76,7 @@ class TiffSaveOptionsData(object):
         'use_gdi_emf_renderer': 'bool',
         'use_high_quality_rendering': 'bool',
         'vertical_resolution': 'float',
+        'save_format': 'str',
         'threshold_for_floyd_steinberg_dithering': 'int',
         'tiff_binarization_method': 'str',
         'tiff_compression': 'str'
@@ -91,7 +91,6 @@ class TiffSaveOptionsData(object):
         'file_name': 'FileName',
         'flat_opc_xml_mapping_only': 'FlatOpcXmlMappingOnly',
         'iml_rendering_mode': 'ImlRenderingMode',
-        'save_format': 'SaveFormat',
         'update_created_time_property': 'UpdateCreatedTimeProperty',
         'update_fields': 'UpdateFields',
         'update_last_printed_property': 'UpdateLastPrintedProperty',
@@ -117,12 +116,13 @@ class TiffSaveOptionsData(object):
         'use_gdi_emf_renderer': 'UseGdiEmfRenderer',
         'use_high_quality_rendering': 'UseHighQualityRendering',
         'vertical_resolution': 'VerticalResolution',
+        'save_format': 'SaveFormat',
         'threshold_for_floyd_steinberg_dithering': 'ThresholdForFloydSteinbergDithering',
         'tiff_binarization_method': 'TiffBinarizationMethod',
         'tiff_compression': 'TiffCompression'
     }
 
-    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, flat_opc_xml_mapping_only=None, iml_rendering_mode=None, save_format=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, horizontal_resolution=None, image_brightness=None, image_color_mode=None, image_contrast=None, paper_color=None, pixel_format=None, resolution=None, scale=None, use_anti_aliasing=None, use_gdi_emf_renderer=None, use_high_quality_rendering=None, vertical_resolution=None, threshold_for_floyd_steinberg_dithering=None, tiff_binarization_method=None, tiff_compression=None):  # noqa: E501
+    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, flat_opc_xml_mapping_only=None, iml_rendering_mode=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, horizontal_resolution=None, image_brightness=None, image_color_mode=None, image_contrast=None, paper_color=None, pixel_format=None, resolution=None, scale=None, use_anti_aliasing=None, use_gdi_emf_renderer=None, use_high_quality_rendering=None, vertical_resolution=None, threshold_for_floyd_steinberg_dithering=None, tiff_binarization_method=None, tiff_compression=None):  # noqa: E501
         """TiffSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
         self._allow_embedding_post_script_fonts = None
@@ -133,7 +133,6 @@ class TiffSaveOptionsData(object):
         self._file_name = None
         self._flat_opc_xml_mapping_only = None
         self._iml_rendering_mode = None
-        self._save_format = None
         self._update_created_time_property = None
         self._update_fields = None
         self._update_last_printed_property = None
@@ -159,6 +158,7 @@ class TiffSaveOptionsData(object):
         self._use_gdi_emf_renderer = None
         self._use_high_quality_rendering = None
         self._vertical_resolution = None
+        self._save_format = "tiff"
         self._threshold_for_floyd_steinberg_dithering = None
         self._tiff_binarization_method = None
         self._tiff_compression = None
@@ -180,8 +180,6 @@ class TiffSaveOptionsData(object):
             self.flat_opc_xml_mapping_only = flat_opc_xml_mapping_only
         if iml_rendering_mode is not None:
             self.iml_rendering_mode = iml_rendering_mode
-        if save_format is not None:
-            self.save_format = save_format
         if update_created_time_property is not None:
             self.update_created_time_property = update_created_time_property
         if update_fields is not None:
@@ -333,7 +331,15 @@ class TiffSaveOptionsData(object):
         :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._dml_effects_rendering_mode = dml_effects_rendering_mode
+        allowed_values = ["Simplified", "None", "Fine"]  # noqa: E501
+        if not dml_effects_rendering_mode.isdigit():
+            if dml_effects_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml_effects_rendering_mode, allowed_values))
+            self._dml_effects_rendering_mode = dml_effects_rendering_mode
+        else:
+            self._dml_effects_rendering_mode = allowed_values[int(dml_effects_rendering_mode) if six.PY3 else long(dml_effects_rendering_mode)]
 
     @property
     def dml_rendering_mode(self):
@@ -355,7 +361,15 @@ class TiffSaveOptionsData(object):
         :param dml_rendering_mode: The dml_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._dml_rendering_mode = dml_rendering_mode
+        allowed_values = ["Fallback", "DrawingML"]  # noqa: E501
+        if not dml_rendering_mode.isdigit():
+            if dml_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml_rendering_mode, allowed_values))
+            self._dml_rendering_mode = dml_rendering_mode
+        else:
+            self._dml_rendering_mode = allowed_values[int(dml_rendering_mode) if six.PY3 else long(dml_rendering_mode)]
 
     @property
     def file_name(self):
@@ -421,29 +435,15 @@ class TiffSaveOptionsData(object):
         :param iml_rendering_mode: The iml_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._iml_rendering_mode = iml_rendering_mode
-
-    @property
-    def save_format(self):
-        """Gets the save_format of this TiffSaveOptionsData.  # noqa: E501
-
-        Gets or sets the format of save.  # noqa: E501
-
-        :return: The save_format of this TiffSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._save_format
-
-    @save_format.setter
-    def save_format(self, save_format):
-        """Sets the save_format of this TiffSaveOptionsData.
-
-        Gets or sets the format of save.  # noqa: E501
-
-        :param save_format: The save_format of this TiffSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._save_format = save_format
+        allowed_values = ["Fallback", "InkML"]  # noqa: E501
+        if not iml_rendering_mode.isdigit():
+            if iml_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `iml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(iml_rendering_mode, allowed_values))
+            self._iml_rendering_mode = iml_rendering_mode
+        else:
+            self._iml_rendering_mode = allowed_values[int(iml_rendering_mode) if six.PY3 else long(iml_rendering_mode)]
 
     @property
     def update_created_time_property(self):
@@ -597,7 +597,15 @@ class TiffSaveOptionsData(object):
         :param color_mode: The color_mode of this TiffSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._color_mode = color_mode
+        allowed_values = ["Normal", "Grayscale"]  # noqa: E501
+        if not color_mode.isdigit():
+            if color_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `color_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(color_mode, allowed_values))
+            self._color_mode = color_mode
+        else:
+            self._color_mode = allowed_values[int(color_mode) if six.PY3 else long(color_mode)]
 
     @property
     def jpeg_quality(self):
@@ -663,7 +671,15 @@ class TiffSaveOptionsData(object):
         :param numeral_format: The numeral_format of this TiffSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._numeral_format = numeral_format
+        allowed_values = ["European", "ArabicIndic", "EasternArabicIndic", "Context", "System"]  # noqa: E501
+        if not numeral_format.isdigit():
+            if numeral_format not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `numeral_format` ({0}), must be one of {1}"  # noqa: E501
+                    .format(numeral_format, allowed_values))
+            self._numeral_format = numeral_format
+        else:
+            self._numeral_format = allowed_values[int(numeral_format) if six.PY3 else long(numeral_format)]
 
     @property
     def optimize_output(self):
@@ -795,7 +811,15 @@ class TiffSaveOptionsData(object):
         :param image_color_mode: The image_color_mode of this TiffSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._image_color_mode = image_color_mode
+        allowed_values = ["None", "Grayscale", "BlackAndWhite"]  # noqa: E501
+        if not image_color_mode.isdigit():
+            if image_color_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `image_color_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(image_color_mode, allowed_values))
+            self._image_color_mode = image_color_mode
+        else:
+            self._image_color_mode = allowed_values[int(image_color_mode) if six.PY3 else long(image_color_mode)]
 
     @property
     def image_contrast(self):
@@ -861,7 +885,15 @@ class TiffSaveOptionsData(object):
         :param pixel_format: The pixel_format of this TiffSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._pixel_format = pixel_format
+        allowed_values = ["Format16BppRgb555", "Format16BppRgb565", "Format16BppArgb1555", "Format24BppRgb", "Format32BppRgb", "Format32BppArgb", "Format32BppPArgb", "Format48BppRgb", "Format64BppArgb", "Format64BppPArgb", "Format1bppIndexed"]  # noqa: E501
+        if not pixel_format.isdigit():
+            if pixel_format not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `pixel_format` ({0}), must be one of {1}"  # noqa: E501
+                    .format(pixel_format, allowed_values))
+            self._pixel_format = pixel_format
+        else:
+            self._pixel_format = allowed_values[int(pixel_format) if six.PY3 else long(pixel_format)]
 
     @property
     def resolution(self):
@@ -995,6 +1027,18 @@ class TiffSaveOptionsData(object):
         """
         self._vertical_resolution = vertical_resolution
 
+    @property
+    def save_format(self):
+        """Gets the save_format of this TiffSaveOptionsData.  # noqa: E501
+
+        Gets the format of save.  # noqa: E501
+
+        :return: The save_format of this TiffSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._save_format
+
+
     @property
     def threshold_for_floyd_steinberg_dithering(self):
         """Gets the threshold_for_floyd_steinberg_dithering of this TiffSaveOptionsData.  # noqa: E501
@@ -1037,7 +1081,15 @@ class TiffSaveOptionsData(object):
         :param tiff_binarization_method: The tiff_binarization_method of this TiffSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._tiff_binarization_method = tiff_binarization_method
+        allowed_values = ["Threshold", "FloydSteinbergDithering"]  # noqa: E501
+        if not tiff_binarization_method.isdigit():
+            if tiff_binarization_method not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `tiff_binarization_method` ({0}), must be one of {1}"  # noqa: E501
+                    .format(tiff_binarization_method, allowed_values))
+            self._tiff_binarization_method = tiff_binarization_method
+        else:
+            self._tiff_binarization_method = allowed_values[int(tiff_binarization_method) if six.PY3 else long(tiff_binarization_method)]
 
     @property
     def tiff_compression(self):
@@ -1059,7 +1111,15 @@ class TiffSaveOptionsData(object):
         :param tiff_compression: The tiff_compression of this TiffSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._tiff_compression = tiff_compression
+        allowed_values = ["None", "Rle", "Lzw", "Ccitt3", "Ccitt4"]  # noqa: E501
+        if not tiff_compression.isdigit():
+            if tiff_compression not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `tiff_compression` ({0}), must be one of {1}"  # noqa: E501
+                    .format(tiff_compression, allowed_values))
+            self._tiff_compression = tiff_compression
+        else:
+            self._tiff_compression = allowed_values[int(tiff_compression) if six.PY3 else long(tiff_compression)]
 
 
     def to_dict(self):
